@@ -8,7 +8,7 @@ no warnings 'uninitialized';
 
 use Carp;
 
-use constant HAS_QUADS => eval { no warnings; pack(Q => 1); 1 } ? 1 : 0;
+use constant HAS_QUADS => eval { no warnings; (undef) = pack(Q => 1); 1 } ? 1 : 0;
 
 
 sub new {
