@@ -74,8 +74,7 @@ BEGIN {
 		      SFTP_ERR_LOCAL_CHMOD_FAILED => 9,
 		      SFTP_ERR_REMOTE_BAD_TIME => 10,
 		      SFTP_ERR_LOCAL_UTIME_FAILED => 11,
-		      SFTP_ERR_REMOTE_BAD_PACKET_TYPE => 12,
-		      SFTP_ERR_REMOTE_BAD_PACKET_SEQUENCE => 13,
+		      SFTP_ERR_REMOTE_BAD_MESSAGE => 13,
 		      SFTP_ERR_REMOTE_REALPATH_FAILED => 14,
 		      SFTP_ERR_REMOTE_OPENDIR_FAILED => 15,
 		      SFTP_ERR_REMOTE_WRITE_FAILED => 16,
@@ -97,7 +96,9 @@ BEGIN {
 		      SFTP_ERR_REMOTE_BAD_PATH => 32,
 		      SFTP_ERR_LOCAL_MKDIR_FAILED => 33,
 		      SFTP_ERR_LOCAL_SYMLINK_FAILED => 34,
-		      SFTP_ERR_REMOTE_BAD_OBJECT => 35 );
+		      SFTP_ERR_REMOTE_BAD_OBJECT => 35,
+		      SFTP_ERR_REMOTE_ACCESING_CLOSED_FILE => 36,
+		      SFTP_ERR_CONNECTION_BROKEN => 37 );
 
     for my $key (keys %constants) {
 	no strict 'refs';
@@ -185,7 +186,6 @@ C<SFTP_ERR_LOCAL_CHMOD_FAILED>, C<SFTP_ERR_LOCAL_OPEN_FAILED>,
 C<SFTP_ERR_LOCAL_READ_ERROR>, C<SFTP_ERR_LOCAL_STAT_FAILED>,
 C<SFTP_ERR_LOCAL_UTIME_FAILED>, C<SFTP_ERR_LOCAL_WRITE_FAILED>,
 C<SFTP_ERR_REMOTE_BAD_PACKET_SEQUENCE>,
-C<SFTP_ERR_REMOTE_BAD_PACKET_TYPE>,
 C<SFTP_ERR_REMOTE_BAD_PERMISSIONS>, C<SFTP_ERR_REMOTE_BAD_TIME>,
 C<SFTP_ERR_REMOTE_BLOCK_TOO_SMALL>, C<SFTP_ERR_REMOTE_CLOSE_FAILED>,
 C<SFTP_ERR_REMOTE_FSETSTAT_FAILED>, C<SFTP_ERR_REMOTE_FSTAT_FAILED>,
